@@ -7,7 +7,17 @@ use warnings;
 
 use Venus::Role 'with';
 
-with 'Venus::Role::Tryable';
+# AUDITS
+
+sub AUDIT {
+  my ($self, $from) = @_;
+
+  if (!$from->does('Venus::Role::Tryable')) {
+    die "${self} requires ${from} to consume Venus::Role::Tryable";
+  }
+
+  return $self;
+}
 
 # METHODS
 
@@ -22,7 +32,7 @@ sub catch {
 # EXPORTS
 
 sub EXPORT {
-  ['catch', 'try']
+  ['catch']
 }
 
 1;
@@ -49,6 +59,7 @@ Catchable Role for Perl 5
 
   use Venus 'error';
 
+  with 'Venus::Role::Tryable';
   with 'Venus::Role::Catchable';
 
   sub pass {
@@ -74,14 +85,6 @@ errors thrown from dispatched method calls.
 
 =cut
 
-=head1 INTEGRATES
-
-This package integrates behaviors from:
-
-L<Venus::Role::Tryable>
-
-=cut
-
 =head1 METHODS
 
 This package provides the following methods:
