@@ -5,7 +5,7 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo::Role;
+use Venus::Role 'with';
 
 # METHODS
 
@@ -20,6 +20,12 @@ sub throw {
   return Venus::Throw->new(package => $package, context => $context);
 }
 
+# EXPORTS
+
+sub EXPORT {
+  ['throw']
+}
+
 1;
 
 
