@@ -5,7 +5,7 @@ use 5.018;
 use strict;
 use warnings;
 
-use Moo::Role;
+use Venus::Role 'with';
 
 # METHODS
 
@@ -21,6 +21,12 @@ sub try {
   return $try->call($callback);
 }
 
+# EXPORTS
+
+sub EXPORT {
+  ['try']
+}
+
 1;
 
 
@@ -41,7 +47,7 @@ Tryable Role for Perl 5
 
   package Example;
 
-  use Venus::Class;
+  use Venus::Class 'with';
   use Venus 'raise';
 
   with 'Venus::Role::Tryable';
